<?php

namespace Flone\Elementor\HeaderFooter;
use Elementor\Plugin as Elementor;
use Elementor\Controls_Manager;
use Elementor\Element_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/** 
*  Header and Footer
*/
class Flone_Header_Footer{

    private static $_instance = null;
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    
    function __construct(){

        // Register Control Document
        add_action( 'elementor/documents/register_controls', [ $this, 'add_elementor_page_settings_controls'], 10, 1 );
    }

    /*
    * Elementor Page Document Setting Add
    */
    public function add_elementor_page_settings_controls( $elementor  ) {

        $elementor->start_controls_section(
            'flone_section_header_options',
            [
                'label' => __( 'Header Layout', 'flone' ),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

            $elementor->add_control(
                'flone_header_style_by_page',
                [
                    'label' => __( 'Header Layout', 'flone' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => '0',
                    'options' => [
                        '0'  => esc_html__( 'Default' , 'flone' ),
                        '1'  => esc_html__( 'Header Style One' , 'flone' ),
                        '2'  => esc_html__( 'Header Style Two' , 'flone' ),
                        '3'  => esc_html__( 'Header Style Three' , 'flone' ),
                        '4'  => esc_html__( 'Header Style Four' , 'flone' ),
                        '5'  => esc_html__( 'Header Style Five' , 'flone' ),
                        '6'  => esc_html__( 'Header Style Six' , 'flone' ),
                        '7'  => esc_html__( 'Header Style Seven' , 'flone' ),
                    ],
                    'label_block'=>true,
                ]
            );

            // header background color 
            $elementor->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'flone_top_header_background',
                    'label' => __( 'Header Top Background', 'flone' ),
                    'types' => [ 'classic', 'gradient' ],
                    'fields_options'=>[
                        'background'=>[
                            'label'=> esc_html__( 'Header Top Background', 'flone' ),
                        ]
                    ],
                    'selector' => '{{WRAPPER}} .header-seven-top',
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Topbar Bottom Border color
            $elementor->add_control(
                'flone_top_header_border_color',
                [
                    'label'     => __( 'Topbar Bottom Border color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-hm9 .header-top-area' => 'border-color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Topbar Left Content Text color
            $elementor->add_control(
                'flone_top_header_left_content_color',
                [
                    'label'     => __( 'Topbar Left Content Text color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency p' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Topbar Left Content Text color
            $elementor->add_control(
                'flone_top_header_left_menu_color',
                [
                    'label'     => __( 'Topbar Left Menu color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency a, {{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency a i' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Topbar Left Menu Hover color
            $elementor->add_control(
                'flone_top_header_left_menu_hover_color',
                [
                    'label'     => __( 'Topbar Left Menu Hover color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency:hover>a, {{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency:hover a i, {{WRAPPER}} .header-seven-top .language-currency-wrap .same-language-currency .lang-car-dropdown ul li a:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Header Seven Botoom Style
            $elementor->add_control(
                'flone_header_page_options',
                [
                    'label' => __( 'Header Seven Botoom Style', 'flone' ),
                    'type' => \Elementor\Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition'=>[
                        'flone_header_style_by_page'=>'7',
                    ],
                ]
            );

            // Header Background
            $elementor->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'flone_header_page_background',
                    'label' => __( 'Header Background', 'flone' ),
                    'types' => [ 'classic', 'gradient' ],
                    'fields_options'=>[
                        'background'=>[
                            'label'=> esc_html__( 'Header Background', 'flone' ),
                        ]
                    ],
                    'selector' => '{{WRAPPER}} .header-padding-3.header_style_5, {{WRAPPER}} .header-bottom, {{WRAPPER}} .flone_header_4.header-padding-3 , {{WRAPPER}} .home-sidebar-left',
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '5', '6', '7'],
                    ],
                ]
            );

            // Clickable Menu Icon Color
            $elementor->add_control(
                'flone_page_clickable_menu_color',
                [
                    'label'     => __( 'Clickable Menu Icon Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-menu a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );

            // Clickable Menu Icon Hover Color
            $elementor->add_control(
                'flone_page_clickable_menu_hover_color',
                [
                    'label'     => __( 'Clickable Menu Icon Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-menu a:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );

            // Header Menu Color
            $elementor->add_control(
                'flone_page_header_menu_color',
                [
                    'label'     => __( 'Header Menu Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li>a, {{WRAPPER}} #primary-menu .menu-item-has-children::after, {{WRAPPER}} .sidebar-menu nav ul li a, {{WRAPPER}} .home-sidebar-left .sidebar-copyright p, {{WRAPPER}} .header-right-wrap .same-style>a, {{WRAPPER}} .header-right-wrap .same-style.cart-wrap button, {{WRAPPER}} .flone_header_4 .main-menu.menu-white nav > ul > li > a, {{WRAPPER}} .flone_header_4 #primary-menu .menu-item-has-children::after, {{WRAPPER}} .header-right-wrap.header-right-wrap-white .same-style>a, {{WRAPPER}} .header-right-wrap.header-right-wrap-white .same-style.cart-wrap>button' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // Header Menu Hover Color
            $elementor->add_control(
                'flone_page_header_menu_hover_color',
                [
                    'label'     => __( 'Header Menu Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu > nav > ul > li:hover > a, {{WRAPPER}} #primary-menu .menu-item-has-children:hover::after, {{WRAPPER}} .sidebar-menu nav > ul > li:hover > a, {{WRAPPER}} .main-menu .sub-menu>li>a:focus, {{WRAPPER}} .header_style_4 .main-menu.menu-white nav ul li:hover>a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // Header Menu Hover Color
            $elementor->add_control(
                'flone_page_header_three_copyright_color',
                [
                    'label'     => __( 'Header Copyright Text Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .home-sidebar-left .sidebar-copyright p' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'3',
                    ],
                ]
            );

            // Header Right Content
            $elementor->add_control(
                'flone_header_after_clicking_options',
                [
                    'label' => __( 'Header Menu After Clicking', 'flone' ),
                    'type' => \Elementor\Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition'=>[
                        'flone_header_style_by_page'=> '5',
                    ],
                ]
            );

            // Close Button Color
            $elementor->add_control(
                'flone_header_after_click_close_color',
                [
                    'label'     => __( 'Close Button Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-mainmenu .clickable-mainmenu-icon button' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );  

            // Close Button Hover Color 
            $elementor->add_control(
                'flone_header_after_click_close_hover_color',
                [
                    'label'     => __( 'Close Button Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-mainmenu .clickable-mainmenu-icon button:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            ); 

            // Header Clickable Menu Color
            $elementor->add_control(
                'flone_header_after_clicking_link_color',
                [
                    'label'     => __( 'Menu Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .slinky-theme-default .next::after, {{WRAPPER}} .clickable-mainmenu .clickable-menu-style ul li a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );  

            // Header Clickable Menu Hover Color
            $elementor->add_control(
                'flone_header_after_clicking_link_hover_color',
                [
                    'label'     => __( 'Menu Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-mainmenu .clickable-menu-style ul li a:hover, {{WRAPPER}} .slinky-theme-default .next:hover::after' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            ); 

            // Menu Back Button Background
            $elementor->add_control(
                'flone_header_after_clicking_menu_back_btn_bg',
                [
                    'label'     => __( 'Back Button Background', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .slinky-theme-default .back::before' => 'background-color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );  

            // Menu Back Button Icon Color
            $elementor->add_control(
                'flone_header_after_clicking_menu_back_btn',
                [
                    'label'     => __( 'Back Button Icon Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .slinky-theme-default .back::before' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );    

            // Menu Back Button Background
            $elementor->add_control(
                'flone_header_after_clicking_menu_back_btn_hover_bg',
                [
                    'label'     => __( 'Back Button Hover Background', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .slinky-theme-default .back:hover::before' => 'background-color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );  

            // Menu Back Button Icon Color
            $elementor->add_control(
                'flone_header_after_clicking_menu_back_hover_btn',
                [
                    'label'     => __( 'Back Button Icon Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .slinky-theme-default .back:hover::before' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );  

            // Social Icon Color
            $elementor->add_control(
                'flone_header_five_social_icon_color',
                [
                    'label'     => __( 'Social Icon Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-mainmenu .side-social ul li a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );   

            // Social Icon Color
            $elementor->add_control(
                'flone_header_five_social_icon_hover_color',
                [
                    'label'     => __( 'Social Icon Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .clickable-mainmenu .side-social ul li a:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>'5',
                    ],
                ]
            );            

            // Header Right Content
            $elementor->add_control(
                'flone_mini_cart_options',
                [
                    'label' => __( 'Header Right Content', 'flone' ),
                    'type' => \Elementor\Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Icons Color Settings
            $elementor->add_control(
                'flone_page_header_right_icons_color',
                [
                    'label'     => __( 'Icons Color Settings', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style>a , {{WRAPPER}} .header-right-wrap .same-style.cart-wrap button' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Icons Hover Color Settings
            $elementor->add_control(
                'flone_page_header_right_icons_hover_color',
                [
                    'label'     => __( 'Icons Hover Color Settings', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style:hover>a, {{WRAPPER}} .header-right-wrap .same-style.cart-wrap:hover>button' => 'color: {{VALUE}} !important;',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // User Menu Background Color
            $elementor->add_control(
                'flone_page_header_user_bg_color',
                [
                    'label'     => __( 'User Menu Background Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style .account-dropdown' => 'background: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Header Right User Color options
            $elementor->add_control(
                'flone_page_header_user_color',
                [
                    'label'     => __( 'User Menu Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style .account-dropdown ul li a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // User Menu Hover Color
            $elementor->add_control(
                'flone_page_header_user_hover_color',
                [
                    'label'     => __( 'User Menu Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style .account-dropdown ul li a:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Mini Cart Counter Background options
            $elementor->add_control(
                'flone_page_header_cart_bg',
                [
                    'label'     => __( 'Mini Cart Counter Background', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.cart-wrap button span.count-style' => 'background-color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Mini Cart Counter Text Color
            $elementor->add_control(
                'flone_page_header_cart_color',
                [
                    'label'     => __( 'Mini Cart Counter Text Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.cart-wrap button span.count-style' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Header Search Button BG
            $elementor->add_control(
                'flone_page_header_search_btn_color',
                [
                    'label'     => __( 'Header Search Button BG', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.header-search .search-content form .button-search' => 'border-color: {{VALUE}};background: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Header Right search button Hover Color options
            $elementor->add_control(
                'flone_page_header_search_btn_hover_color',
                [
                    'label'     => __( 'Header Search Button Hover BG', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.header-search .search-content form .button-search:hover' => 'border-color: {{VALUE}};background: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Header Right search button Hover Color options
            $elementor->add_control(
                'flone_page_header_search_icon_color',
                [
                    'label'     => __( 'Header Search Icon Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.header-search .search-content form .button-search' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Header Right search button Hover Color options
            $elementor->add_control(
                'flone_page_header_search_icon_hover_color',
                [
                    'label'     => __( 'Header Search Icon Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .header-right-wrap .same-style.header-search .search-content form .button-search:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['2', '3', '4', '5', '7'],
                    ],
                ]
            );

            // Mega/Sub Menu Options
            $elementor->add_control(
                'flone_meag_sub_menu_options',
                [
                    'label' => __( 'Mega/Sub Menu Options', 'flone' ),
                    'type' => \Elementor\Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // Mega/Sub menu background color
            $elementor->add_control(
                'flone_header_page_mega_menu_background',
                [
                    'label'     => __( 'Mega/Sub Menu Background', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li ul.mega-menu, {{WRAPPER}} .sidebar-menu nav ul li ul.mega-menu,{{WRAPPER}} .main-menu nav ul li ul.sub-menu, {{WRAPPER}} .sidebar-menu nav ul li ul.sub-menu' => 'background-color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // header menu hover color
            $elementor->add_control(
                'flone_page_mega_menu_title_color_option',
                [
                    'label'     => __( 'Title Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li ul.mega-menu li a.menu_title' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // header menu hover color
            $elementor->add_control(
                'flone_page_mega_menu_color_option',
                [
                    'label'     => __( 'Primary Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li ul.mega-menu>li ul li a, {{WRAPPER}} .sidebar-menu nav ul li ul.mega-menu>li ul li a,{{WRAPPER}} .main-menu nav ul li ul.sub-menu li a, {{WRAPPER}} .sidebar-menu nav ul li ul.sub-menu li a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // header menu hover color
            $elementor->add_control(
                'flone_page_mega_menu_hover_color_option',
                [
                    'label'     => __( 'Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li ul.mega-menu>li ul li:hover a, {{WRAPPER}} .sidebar-menu nav ul li ul.mega-menu>li ul li:hover a, {{WRAPPER}} .main-menu nav ul li ul.mega-menu>li ul li a::before, {{WRAPPER}} .sidebar-menu nav ul li ul.mega-menu>li ul li a::before, {{WRAPPER}} .main-menu nav ul li ul.sub-menu li a::before, {{WRAPPER}} .sidebar-menu nav ul li ul.sub-menu li a::before, {{WRAPPER}} .main-menu nav ul li ul.sub-menu li a:hover, {{WRAPPER}} .sidebar-menu nav ul li ul.sub-menu li a:hover' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // header menu hover color
            $elementor->add_control(
                'flone_page_mega_menu_hover_dot_color_option',
                [
                    'label'     => __( 'Dot Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .main-menu nav ul li ul.mega-menu>li ul li a::before, {{WRAPPER}} .sidebar-menu nav ul li ul.mega-menu>li ul li a::before, {{WRAPPER}} .main-menu nav ul li ul.sub-menu li a::before, {{WRAPPER}} .sidebar-menu nav ul li ul.sub-menu li a::before' => 'color: {{VALUE}};background: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '6', '7'],
                    ],
                ]
            );

            // Divider Two
            $elementor->add_control(
                'flone_hr2',
                [
                    'type' => \Elementor\Controls_Manager::DIVIDER,
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '3', '4', '5', '6', '7'],
                    ],
                ]
            );

            // Sticky Header title
            $elementor->add_control(
                'flone_header_sticky_options',
                [
                    'label' => __( 'Header Sticky Options', 'flone' ),
                    'type' => \Elementor\Controls_Manager::HEADING,
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '4', '5', '6', '7'],
                    ],
                ]
            );

            // header sticky background color
            $elementor->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'flone_sticky_header_page_background',
                    'label' => __( 'Sticky Header Background', 'flone' ),
                    'types' => [ 'classic', 'gradient' ],
                    'fields_options'=>[
                        'background'=>[
                            'label'=> esc_html__( 'Header Background', 'flone' ),
                        ]
                    ],
                    'selector' => '{{WRAPPER}} .sticky-bar.stick',
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '4', '5', '6', '7'],
                    ],
                ]
            );

            // Sticky header menu color 
            $elementor->add_control(
                'flone_page_sticky_header_menu_color',
                [
                    'label'     => __( 'Sticky Menu Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .stick .main-menu nav ul li>a, {{WRAPPER}} .stick nav ul#primary-menu > li.menu-item-has-children > a::after , {{WRAPPER}} .flone_header_4 .stick .main-menu.menu-white nav ul li a' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '4', '5', '6', '7'],
                    ],
                ]
            );

            // Sticky header menu color 
            $elementor->add_control(
                'flone_page_sticky_header_menu_hover_color',
                [
                    'label'     => __( 'Sticky Menu Hover Color', 'flone' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .stick .main-menu nav > ul > li:hover > a , {{WRAPPER}} .flone_header_4 .stick .main-menu.menu-white nav ul li a:hover, {{WRAPPER}} .flone_header_4 .stick nav ul#primary-menu > li.menu-item-has-children:hover > a::after' => 'color: {{VALUE}};',
                    ],
                    'condition'=>[
                        'flone_header_style_by_page'=>['1', '2', '4', '5', '6', '7'],
                    ],
                ]
            );

        $elementor->end_controls_section();

        $elementor->start_controls_section(
            'flone_section_footer_options',
            [
                'label' => __( 'Footer Layout', 'flone' ),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

            //Fotter Styles
            $elementor->add_control(
                'flone_footer_style_by_page',
                [
                    'label' => __( 'Footer Layout', 'flone' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => '0',
                    'options' => [
                        '0'  => esc_html__( 'Default' , 'flone' ),
                        '1'  => esc_html__( 'Footer Style One' , 'flone' ),
                        '2'  => esc_html__( 'Footer Style Two' , 'flone' ),
                        '3'  => esc_html__( 'Footer Style Three' , 'flone' )
                    ],
                    'label_block'=>true,
                    'separator'=>'before',
                ]
            );   
           
        $elementor->end_controls_section();                 

    }

}

Flone_Header_Footer::instance();